Class: Google::Apis::CloudnumberregistryV1alpha::CleanupIpamAdminScopeRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::CleanupIpamAdminScopeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Request message for the CloudNumberRegistry.CleanupIpamAdminScope method.
Instance Attribute Summary collapse
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CleanupIpamAdminScopeRequest
constructor
A new instance of CleanupIpamAdminScopeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CleanupIpamAdminScopeRequest
Returns a new instance of CleanupIpamAdminScopeRequest.
144 145 146 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes after the first request. For example, consider a
situation where you make an initial request and the request times out. If you
make the request again with the same request ID, the server can check if
original operation with the same request ID was received, and if so, will
ignore the second request. This prevents clients from accidentally creating
duplicate commitments. The request ID must be a valid UUID with the exception
that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
142 143 144 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 142 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
149 150 151 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 149 def update!(**args) @request_id = args[:request_id] if args.key?(:request_id) end |