Class: Google::Apis::CloudnumberregistryV1alpha::CloudNumberRegistryService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::CloudnumberregistryV1alpha::CloudNumberRegistryService
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/service.rb
Overview
Cloud Number Registry API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://cloudnumberregistry.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Empty
Starts asynchronous cancellation on a long-running operation.
-
#check_project_location_ipam_admin_scope_availability(parent, scopes: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::CheckAvailabilityIpamAdminScopesResponse
Checks the availability of IpamAdminScopes in a given project and location.
-
#cleanup_ipam_admin_scope(name, cleanup_ipam_admin_scope_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Cleans up a single IpamAdminScope.
-
#create_project_location_custom_range(parent, custom_range_object = nil, custom_range_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Creates a new CustomRange in a given project and location.
-
#create_project_location_ipam_admin_scope(parent, ipam_admin_scope_object = nil, ipam_admin_scope_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Creates a new IpamAdminScope in a given project and location.
-
#create_project_location_realm(parent, realm_object = nil, realm_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Creates a new Realm in a given project and location.
-
#create_project_location_registry_book(parent, registry_book_object = nil, registry_book_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Creates a new RegistryBook in a given project and location.
-
#delete_project_location_custom_range(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Deletes a single CustomRange.
-
#delete_project_location_ipam_admin_scope(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Deletes a single IpamAdminScope.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Empty
Deletes a long-running operation.
-
#delete_project_location_realm(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Deletes a single Realm.
-
#delete_project_location_registry_book(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Deletes a single RegistryBook.
-
#disable_ipam_admin_scope(name, disable_ipam_admin_scope_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Disables a single IpamAdminScope.
-
#find_project_location_custom_range_free_ip_ranges(name, cidr_prefix_length: nil, range_count: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::FindCustomRangeFreeIpRangesResponse
Finds free IP ranges in a single CustomRange.
-
#find_project_location_discovered_range_free_ip_ranges(name, cidr_prefix_length: nil, range_count: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::FindDiscoveredRangeFreeIpRangesResponse
Finds free IP ranges in a single DiscoveredRange.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Location
Gets information about a location.
-
#get_project_location_custom_range(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::CustomRange
Gets details of a single CustomRange.
-
#get_project_location_discovered_range(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::DiscoveredRange
Gets details of a single DiscoveredRange.
-
#get_project_location_ipam_admin_scope(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::IpamAdminScope
Gets details of a single IpamAdminScope.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_realm(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Realm
Gets details of a single Realm.
-
#get_project_location_registry_book(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::RegistryBook
Gets details of a single RegistryBook.
-
#initialize ⇒ CloudNumberRegistryService
constructor
A new instance of CloudNumberRegistryService.
-
#list_project_location_custom_ranges(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListCustomRangesResponse
Lists CustomRanges in a given project and location.
-
#list_project_location_discovered_ranges(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListDiscoveredRangesResponse
Lists DiscoveredRanges in a given project and location.
-
#list_project_location_ipam_admin_scopes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListIpamAdminScopesResponse
Lists IpamAdminScopes in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_realms(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListRealmsResponse
Lists Realms in a given project and location.
-
#list_project_location_registry_books(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListRegistryBooksResponse
Lists RegistryBooks in a given project and location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_custom_range(name, custom_range_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Updates the parameters of a single CustomRange.
-
#patch_project_location_ipam_admin_scope(name, ipam_admin_scope_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Updates the parameters of a single IpamAdminScope.
-
#patch_project_location_realm(name, realm_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Updates the parameters of a single Realm.
-
#patch_project_location_registry_book(name, registry_book_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Updates the parameters of a single RegistryBook.
-
#search_registry_book_ip_resources(name, search_ip_resources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResponse
Searches IP resources in a given RegistryBook.
-
#show_project_location_custom_range_utilization(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ShowCustomRangeUtilizationResponse
Gets the details of a single CustomRange and its utilization.
-
#show_project_location_discovered_range_utilization(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ShowDiscoveredRangeUtilizationResponse
Gets the details of a single DiscoveredRange and its utilization.
Constructor Details
#initialize ⇒ CloudNumberRegistryService
Returns a new instance of CloudNumberRegistryService.
47 48 49 50 51 52 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-cloudnumberregistry_v1alpha', client_version: Google::Apis::CloudnumberregistryV1alpha::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
935 936 937 938 939 940 941 942 943 944 945 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 935 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+name}:cancel', ) command.request_representation = Google::Apis::CloudnumberregistryV1alpha::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Empty::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#check_project_location_ipam_admin_scope_availability(parent, scopes: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::CheckAvailabilityIpamAdminScopesResponse
Checks the availability of IpamAdminScopes in a given project and location.
611 612 613 614 615 616 617 618 619 620 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 611 def check_project_location_ipam_admin_scope_availability(parent, scopes: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/ipamAdminScopes:checkAvailability', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::CheckAvailabilityIpamAdminScopesResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::CheckAvailabilityIpamAdminScopesResponse command.params['parent'] = parent unless parent.nil? command.query['scopes'] = scopes unless scopes.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cleanup_ipam_admin_scope(name, cleanup_ipam_admin_scope_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Cleans up a single IpamAdminScope.
643 644 645 646 647 648 649 650 651 652 653 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 643 def cleanup_ipam_admin_scope(name, cleanup_ipam_admin_scope_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+name}:cleanup', ) command.request_representation = Google::Apis::CloudnumberregistryV1alpha::CleanupIpamAdminScopeRequest::Representation command.request_object = cleanup_ipam_admin_scope_request_object command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_custom_range(parent, custom_range_object = nil, custom_range_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Creates a new CustomRange in a given project and location.
175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 175 def create_project_location_custom_range(parent, custom_range_object = nil, custom_range_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/customRanges', ) command.request_representation = Google::Apis::CloudnumberregistryV1alpha::CustomRange::Representation command.request_object = custom_range_object command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['customRangeId'] = custom_range_id unless custom_range_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_ipam_admin_scope(parent, ipam_admin_scope_object = nil, ipam_admin_scope_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Creates a new IpamAdminScope in a given project and location.
690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 690 def create_project_location_ipam_admin_scope(parent, ipam_admin_scope_object = nil, ipam_admin_scope_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/ipamAdminScopes', ) command.request_representation = Google::Apis::CloudnumberregistryV1alpha::IpamAdminScope::Representation command.request_object = ipam_admin_scope_object command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['ipamAdminScopeId'] = ipam_admin_scope_id unless ipam_admin_scope_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_realm(parent, realm_object = nil, realm_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Creates a new Realm in a given project and location.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1089 def create_project_location_realm(parent, realm_object = nil, realm_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/realms', ) command.request_representation = Google::Apis::CloudnumberregistryV1alpha::Realm::Representation command.request_object = realm_object command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['realmId'] = realm_id unless realm_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_registry_book(parent, registry_book_object = nil, registry_book_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Creates a new RegistryBook in a given project and location.
1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1299 def create_project_location_registry_book(parent, registry_book_object = nil, registry_book_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+parent}/registryBooks', ) command.request_representation = Google::Apis::CloudnumberregistryV1alpha::RegistryBook::Representation command.request_object = registry_book_object command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['registryBookId'] = registry_book_id unless registry_book_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_custom_range(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Deletes a single CustomRange.
222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 222 def delete_project_location_custom_range(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_ipam_admin_scope(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Deletes a single IpamAdminScope.
737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 737 def delete_project_location_ipam_admin_scope(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
970 971 972 973 974 975 976 977 978 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 970 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Empty::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_realm(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Deletes a single Realm.
1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1130 def delete_project_location_realm(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_registry_book(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Deletes a single RegistryBook.
1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1346 def delete_project_location_registry_book(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#disable_ipam_admin_scope(name, disable_ipam_admin_scope_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Disables a single IpamAdminScope.
770 771 772 773 774 775 776 777 778 779 780 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 770 def disable_ipam_admin_scope(name, disable_ipam_admin_scope_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+name}:disable', ) command.request_representation = Google::Apis::CloudnumberregistryV1alpha::DisableIpamAdminScopeRequest::Representation command.request_object = disable_ipam_admin_scope_request_object command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#find_project_location_custom_range_free_ip_ranges(name, cidr_prefix_length: nil, range_count: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::FindCustomRangeFreeIpRangesResponse
Finds free IP ranges in a single CustomRange.
269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 269 def find_project_location_custom_range_free_ip_ranges(name, cidr_prefix_length: nil, range_count: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}:findFreeIpRanges', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::FindCustomRangeFreeIpRangesResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::FindCustomRangeFreeIpRangesResponse command.params['name'] = name unless name.nil? command.query['cidrPrefixLength'] = cidr_prefix_length unless cidr_prefix_length.nil? command.query['rangeCount'] = range_count unless range_count.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#find_project_location_discovered_range_free_ip_ranges(name, cidr_prefix_length: nil, range_count: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::FindDiscoveredRangeFreeIpRangesResponse
Finds free IP ranges in a single DiscoveredRange.
473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 473 def find_project_location_discovered_range_free_ip_ranges(name, cidr_prefix_length: nil, range_count: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}:findFreeIpRanges', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::FindDiscoveredRangeFreeIpRangesResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::FindDiscoveredRangeFreeIpRangesResponse command.params['name'] = name unless name.nil? command.query['cidrPrefixLength'] = cidr_prefix_length unless cidr_prefix_length.nil? command.query['rangeCount'] = range_count unless range_count.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Location::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_custom_range(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::CustomRange
Gets details of a single CustomRange.
302 303 304 305 306 307 308 309 310 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 302 def get_project_location_custom_range(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::CustomRange::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::CustomRange command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_discovered_range(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::DiscoveredRange
Gets details of a single DiscoveredRange.
506 507 508 509 510 511 512 513 514 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 506 def get_project_location_discovered_range(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::DiscoveredRange::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::DiscoveredRange command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_ipam_admin_scope(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::IpamAdminScope
Gets details of a single IpamAdminScope.
802 803 804 805 806 807 808 809 810 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 802 def get_project_location_ipam_admin_scope(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::IpamAdminScope::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::IpamAdminScope command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1001 1002 1003 1004 1005 1006 1007 1008 1009 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1001 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_realm(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Realm
Gets details of a single Realm.
1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1164 def get_project_location_realm(name, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Realm::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Realm command.params['name'] = name unless name.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_registry_book(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::RegistryBook
Gets details of a single RegistryBook.
1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1380 def get_project_location_registry_book(name, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::RegistryBook::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::RegistryBook command.params['name'] = name unless name.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_custom_ranges(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListCustomRangesResponse
Lists CustomRanges in a given project and location.
341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 341 def list_project_location_custom_ranges(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/customRanges', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::ListCustomRangesResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::ListCustomRangesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_discovered_ranges(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListDiscoveredRangesResponse
Lists DiscoveredRanges in a given project and location.
545 546 547 548 549 550 551 552 553 554 555 556 557 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 545 def list_project_location_discovered_ranges(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/discoveredRanges', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::ListDiscoveredRangesResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::ListDiscoveredRangesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_ipam_admin_scopes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListIpamAdminScopesResponse
Lists IpamAdminScopes in a given project and location.
841 842 843 844 845 846 847 848 849 850 851 852 853 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 841 def list_project_location_ipam_admin_scopes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/ipamAdminScopes', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::ListIpamAdminScopesResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::ListIpamAdminScopesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1046 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}/operations', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::ListOperationsResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_realms(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListRealmsResponse
Lists Realms in a given project and location.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1206 def list_project_location_realms(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/realms', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::ListRealmsResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::ListRealmsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_registry_books(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListRegistryBooksResponse
Lists RegistryBooks in a given project and location.
1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1422 def list_project_location_registry_books(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+parent}/registryBooks', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::ListRegistryBooksResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::ListRegistryBooksResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 126 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}/locations', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::ListLocationsResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_custom_range(name, custom_range_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Updates the parameters of a single CustomRange.
394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 394 def patch_project_location_custom_range(name, custom_range_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::CloudnumberregistryV1alpha::CustomRange::Representation command.request_object = custom_range_object command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_ipam_admin_scope(name, ipam_admin_scope_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Updates the parameters of a single IpamAdminScope.
893 894 895 896 897 898 899 900 901 902 903 904 905 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 893 def patch_project_location_ipam_admin_scope(name, ipam_admin_scope_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::CloudnumberregistryV1alpha::IpamAdminScope::Representation command.request_object = ipam_admin_scope_object command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_realm(name, realm_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Updates the parameters of a single Realm.
1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1250 def patch_project_location_realm(name, realm_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::CloudnumberregistryV1alpha::Realm::Representation command.request_object = realm_object command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_registry_book(name, registry_book_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::Operation
Updates the parameters of a single RegistryBook.
1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1475 def patch_project_location_registry_book(name, registry_book_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/{+name}', ) command.request_representation = Google::Apis::CloudnumberregistryV1alpha::RegistryBook::Representation command.request_object = registry_book_object command.response_representation = Google::Apis::CloudnumberregistryV1alpha::Operation::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_registry_book_ip_resources(name, search_ip_resources_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResponse
Searches IP resources in a given RegistryBook.
1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 1510 def search_registry_book_ip_resources(name, search_ip_resources_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/{+name}:searchIpResources', ) command.request_representation = Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesRequest::Representation command.request_object = search_ip_resources_request_object command.response_representation = Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#show_project_location_custom_range_utilization(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ShowCustomRangeUtilizationResponse
Gets the details of a single CustomRange and its utilization.
428 429 430 431 432 433 434 435 436 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 428 def show_project_location_custom_range_utilization(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}:showUtilization', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::ShowCustomRangeUtilizationResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::ShowCustomRangeUtilizationResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#show_project_location_discovered_range_utilization(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudnumberregistryV1alpha::ShowDiscoveredRangeUtilizationResponse
Gets the details of a single DiscoveredRange and its utilization.
579 580 581 582 583 584 585 586 587 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/service.rb', line 579 def show_project_location_discovered_range_utilization(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}:showUtilization', ) command.response_representation = Google::Apis::CloudnumberregistryV1alpha::ShowDiscoveredRangeUtilizationResponse::Representation command.response_class = Google::Apis::CloudnumberregistryV1alpha::ShowDiscoveredRangeUtilizationResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |