Class: Google::Apis::CloudnumberregistryV1alpha::DiscoveredRange

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb

Overview

A DiscoveredRange represents an IP address range automatically detected by the discovery pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveredRange

Returns a new instance of DiscoveredRange.



334
335
336
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesArray<Google::Apis::CloudnumberregistryV1alpha::Attribute>

Optional. The attributes of the DiscoveredRange. Corresponds to the JSON property attributes



267
268
269
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 267

def attributes
  @attributes
end

#child_cidr_overlap_allowedBoolean Also known as: child_cidr_overlap_allowed?

Output only. If true, allows child DiscoveredRanges of this DiscoveredRange to overlap with each other. Corresponds to the JSON property childCidrOverlapAllowed

Returns:

  • (Boolean)


273
274
275
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 273

def child_cidr_overlap_allowed
  @child_cidr_overlap_allowed
end

#create_timeString

Output only. The time at which the DiscoveredRange was created. Corresponds to the JSON property createTime

Returns:

  • (String)


279
280
281
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 279

def create_time
  @create_time
end

#descriptionString

Optional. Description of the DiscoveredRange. Corresponds to the JSON property description

Returns:

  • (String)


284
285
286
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 284

def description
  @description
end

#discovery_metadataGoogle::Apis::CloudnumberregistryV1alpha::DiscoveryMetadata

Metadata about a discovered resource, tracking event times, state, and source information. Corresponds to the JSON property discoveryMetadata



290
291
292
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 290

def 
  @discovery_metadata
end

#ipv4_cidr_rangeString

Optional. The IPv4 CIDR range of the DiscoveredRange. Corresponds to the JSON property ipv4CidrRange

Returns:

  • (String)


295
296
297
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 295

def ipv4_cidr_range
  @ipv4_cidr_range
end

#ipv6_cidr_rangeString

Optional. The IPv6 CIDR range of the DiscoveredRange. Corresponds to the JSON property ipv6CidrRange

Returns:

  • (String)


300
301
302
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 300

def ipv6_cidr_range
  @ipv6_cidr_range
end

#labelsHash<String,String>

Optional. User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


305
306
307
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 305

def labels
  @labels
end

#nameString

Required. Identifier. The resource name of the DiscoveredRange, in the format projects/project/locations/location/discoveredRanges/discovered_range`. Corresponds to the JSON propertyname`

Returns:

  • (String)


311
312
313
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 311

def name
  @name
end

#parent_rangeString

Optional. The resource name of the parent DiscoveredRange, in the format projects/project/locations/location/discoveredRanges/discovered_range`. Corresponds to the JSON propertyparentRange`

Returns:

  • (String)


317
318
319
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 317

def parent_range
  @parent_range
end

#realmString

Optional. The Realm of the DiscoveredRange. Corresponds to the JSON property realm

Returns:

  • (String)


322
323
324
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 322

def realm
  @realm
end

#registry_bookString

Output only. The RegistryBook of the DiscoveredRange. Corresponds to the JSON property registryBook

Returns:

  • (String)


327
328
329
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 327

def registry_book
  @registry_book
end

#update_timeString

Output only. The time at which the DiscoveredRange was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


332
333
334
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 332

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 339

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @child_cidr_overlap_allowed = args[:child_cidr_overlap_allowed] if args.key?(:child_cidr_overlap_allowed)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @discovery_metadata = args[:discovery_metadata] if args.key?(:discovery_metadata)
  @ipv4_cidr_range = args[:ipv4_cidr_range] if args.key?(:ipv4_cidr_range)
  @ipv6_cidr_range = args[:ipv6_cidr_range] if args.key?(:ipv6_cidr_range)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @parent_range = args[:parent_range] if args.key?(:parent_range)
  @realm = args[:realm] if args.key?(:realm)
  @registry_book = args[:registry_book] if args.key?(:registry_book)
  @update_time = args[:update_time] if args.key?(:update_time)
end