Class: Google::Apis::CloudnumberregistryV1alpha::DiscoveryMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb

Overview

Metadata about a discovered resource, tracking event times, state, and source information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveryMetadata

Returns a new instance of DiscoveryMetadata.



406
407
408
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


364
365
366
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 364

def create_time
  @create_time
end

#event_timeString

Output only. The time when the event happened. Corresponds to the JSON property eventTime

Returns:

  • (String)


369
370
371
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 369

def event_time
  @event_time
end

#resourceString

Output only. The resource name of the discovered resource, should be API- agnostic. Example: "projects/project_number/networks/network_id". Corresponds to the JSON property resource

Returns:

  • (String)


375
376
377
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 375

def resource
  @resource
end

#resource_uriString

Output only. The resource uri of the discovered resource. Corresponds to the JSON property resourceUri

Returns:

  • (String)


380
381
382
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 380

def resource_uri
  @resource_uri
end

#source_idString

Output only. The canonical google.aip.dev/122 name of the source resource. Corresponds to the JSON property sourceId

Returns:

  • (String)


385
386
387
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 385

def source_id
  @source_id
end

#source_sub_idString

Output only. A single source resource can be the source of multiple CNR resources. This sub_id is used to distinguish between the different CNR resources derived from the same upstream resource. For example, a single subnetwork can be the source of multiple Ranges, one for each protocol. In this case, the sub_id could be "private-ipv4" or "private-ipv6". Corresponds to the JSON property sourceSubId

Returns:

  • (String)


394
395
396
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 394

def source_sub_id
  @source_sub_id
end

#stateString

Output only. The state of the resource. Corresponds to the JSON property state

Returns:

  • (String)


399
400
401
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 399

def state
  @state
end

#update_timeString

Output only. The time when the resource was last modified. Corresponds to the JSON property updateTime

Returns:

  • (String)


404
405
406
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 404

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



411
412
413
414
415
416
417
418
419
420
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 411

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @event_time = args[:event_time] if args.key?(:event_time)
  @resource = args[:resource] if args.key?(:resource)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @source_id = args[:source_id] if args.key?(:source_id)
  @source_sub_id = args[:source_sub_id] if args.key?(:source_sub_id)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end