Class: Google::Apis::CloudnumberregistryV1alpha::Realm

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb

Overview

A Realm represents a distinct network domain or security zone. It groups Ranges that share the same traffic and management characteristics. All the ranges in a Realm are routable to each other, meaning that they cannot overlap.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Realm

Returns a new instance of Realm.



1079
1080
1081
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregated_dataGoogle::Apis::CloudnumberregistryV1alpha::RealmAggregatedData

Aggregated data for the Realm. Corresponds to the JSON property aggregatedData



1031
1032
1033
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1031

def aggregated_data
  @aggregated_data
end

#create_timeString

Output only. The time at which the Realm was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1036
1037
1038
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1036

def create_time
  @create_time
end

#discovery_metadataGoogle::Apis::CloudnumberregistryV1alpha::DiscoveryMetadata

Metadata about a discovered resource, tracking event times, state, and source information. Corresponds to the JSON property discoveryMetadata



1042
1043
1044
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1042

def 
  @discovery_metadata
end

#ip_versionString

Optional. IP version of the Realm. Corresponds to the JSON property ipVersion

Returns:

  • (String)


1047
1048
1049
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1047

def ip_version
  @ip_version
end

#labelsHash<String,String>

Optional. User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1052
1053
1054
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1052

def labels
  @labels
end

#management_typeString

Required. Management type of the Realm. Corresponds to the JSON property managementType

Returns:

  • (String)


1057
1058
1059
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1057

def management_type
  @management_type
end

#nameString

Required. Identifier. The resource name of the Realm. Corresponds to the JSON property name

Returns:

  • (String)


1062
1063
1064
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1062

def name
  @name
end

#registry_bookString

Required. Name of the RegistryBook that claims the Realm. Corresponds to the JSON property registryBook

Returns:

  • (String)


1067
1068
1069
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1067

def registry_book
  @registry_book
end

#traffic_typeString

Required. Traffic type of the Realm. Corresponds to the JSON property trafficType

Returns:

  • (String)


1072
1073
1074
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1072

def traffic_type
  @traffic_type
end

#update_timeString

Output only. The time at which the Realm was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1077
1078
1079
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1077

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1084

def update!(**args)
  @aggregated_data = args[:aggregated_data] if args.key?(:aggregated_data)
  @create_time = args[:create_time] if args.key?(:create_time)
  @discovery_metadata = args[:discovery_metadata] if args.key?(:discovery_metadata)
  @ip_version = args[:ip_version] if args.key?(:ip_version)
  @labels = args[:labels] if args.key?(:labels)
  @management_type = args[:management_type] if args.key?(:management_type)
  @name = args[:name] if args.key?(:name)
  @registry_book = args[:registry_book] if args.key?(:registry_book)
  @traffic_type = args[:traffic_type] if args.key?(:traffic_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end