Class: Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb

Overview

Request message for the CloudNumberRegistry.SearchIpResources method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchIpResourcesRequest

Returns a new instance of SearchIpResourcesRequest.



1240
1241
1242
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#order_byString

Optional. Hint for how to order the results. Supported sort fields are: - name: Sort alphabetically by the resource name. - create_time: Sort by the creation timestamp of the resource. - update_time: Sort by the last update timestamp of the resource. Supported directions are asc (ascending) and desc (descending). If unspecified, direction defaults to asc. Only sorting by a single field is supported. Corresponds to the JSON property orderBy

Returns:

  • (String)


1194
1195
1196
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1194

def order_by
  @order_by
end

#page_sizeFixnum

Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


1200
1201
1202
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1200

def page_size
  @page_size
end

#page_tokenString

Optional. A token identifying a page of results the server should return. Corresponds to the JSON property pageToken

Returns:

  • (String)


1205
1206
1207
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1205

def page_token
  @page_token
end

#queryString

Optional. Search query. This string filters resources in an AIP-160-like format. It has some limitations. You can only specify top level conjunctions or attribute level negations. Each restriction can only be used once except the attribute restriction. The available restrictions for Ranges are: - realm : The Realm name to search in. - ip_address: The IP address to search for within Ranges. - ip_version: The IP version to filter by (e.g., "IPV4", " IPV6"). - parent_range: The parent Range of the Range to search for. - attribute_text: The attribute text to search for within Ranges. - attribute: The attribute key and value to filter by. The available restrictions for Realms are: - ip_version: The IP version to search for. - management_type: The management type of the Realm (e.g., "CNR", "USER"). Only one of attribute_text or multiple attribute filters can be specified. Examples: - realm=test-realm - realm=test-realm AND ip_address=10.0.0.0 - realm=test- realm AND ip_version=IPV6 - realm=test-realm AND attribute_text=test - ip_address=10.0.0.0 AND attribute:(key1=value1) AND attribute:(key2=value2) - attribute_text=test AND parent_range=projects/123/locations/global/ discoveredRanges/test-parent-range - management_type=CNR Corresponds to the JSON property query

Returns:

  • (String)


1226
1227
1228
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1226

def query
  @query
end

#search_resource_typesArray<String>

Optional. The type of resources to search for. If not specified, the server will return Ranges. Corresponds to the JSON property searchResourceTypes

Returns:

  • (Array<String>)


1232
1233
1234
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1232

def search_resource_types
  @search_resource_types
end

#show_utilizationBoolean Also known as: show_utilization?

Optional. Whether to show the utilization of the Ranges in the response. Corresponds to the JSON property showUtilization

Returns:

  • (Boolean)


1237
1238
1239
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1237

def show_utilization
  @show_utilization
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1245
1246
1247
1248
1249
1250
1251
1252
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1245

def update!(**args)
  @order_by = args[:order_by] if args.key?(:order_by)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @query = args[:query] if args.key?(:query)
  @search_resource_types = args[:search_resource_types] if args.key?(:search_resource_types)
  @show_utilization = args[:show_utilization] if args.key?(:show_utilization)
end