Class: Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Response message for the CloudNumberRegistry.SearchIpResources method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#ranges ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::Range>
Deprecated: Use results field instead.
-
#results ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResult>
The list of results matching the search query.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchIpResourcesResponse
constructor
A new instance of SearchIpResourcesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchIpResourcesResponse
Returns a new instance of SearchIpResourcesResponse.
1280 1281 1282 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1262 1263 1264 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1262 def next_page_token @next_page_token end |
#ranges ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::Range>
Deprecated: Use results field instead. The list of Ranges matching the search
query.
Corresponds to the JSON property ranges
1268 1269 1270 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1268 def ranges @ranges end |
#results ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResult>
The list of results matching the search query.
Corresponds to the JSON property results
1273 1274 1275 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1273 def results @results end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1278 1279 1280 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1278 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1285 1286 1287 1288 1289 1290 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1285 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @ranges = args[:ranges] if args.key?(:ranges) @results = args[:results] if args.key?(:results) @unreachable = args[:unreachable] if args.key?(:unreachable) end |