Module: Google::Apis::CloudnumberregistryV1alpha
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha.rb,
lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/service.rb,
lib/google/apis/cloudnumberregistry_v1alpha/gem_version.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Cloud Number Registry API
Defined Under Namespace
Classes: AggregatedData, Attribute, CancelOperationRequest, CheckAvailabilityIpamAdminScopesResponse, CleanupIpamAdminScopeRequest, CloudNumberRegistryService, CustomRange, DisableIpamAdminScopeRequest, DiscoveredRange, DiscoveryMetadata, Empty, FindCustomRangeFreeIpRangesResponse, FindDiscoveredRangeFreeIpRangesResponse, IpamAdminScope, IpamAdminScopeAvailability, ListCustomRangesResponse, ListDiscoveredRangesResponse, ListIpamAdminScopesResponse, ListLocationsResponse, ListOperationsResponse, ListRealmsResponse, ListRegistryBooksResponse, Location, Operation, OperationMetadata, Range, RangeUtilization, Realm, RealmAggregatedData, RegistryBook, SearchIpResourcesRequest, SearchIpResourcesResponse, SearchIpResourcesResult, ShowCustomRangeUtilizationResponse, ShowDiscoveredRangeUtilizationResponse, Status
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-cloudnumberregistry_v1alpha gem
"0.1.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20260506"- VERSION =
Version of the Cloud Number Registry API this client connects to. This is NOT the gem version.
'V1alpha'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'