Class: Google::Apis::CloudnumberregistryV1alpha::CustomRange
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::CustomRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
A CustomRange represents a user-defined IP address range.
Instance Attribute Summary collapse
-
#attributes ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::Attribute>
Optional.
-
#description ⇒ String
Optional.
-
#ipv4_cidr_range ⇒ String
Optional.
-
#ipv6_cidr_range ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Required.
-
#parent_range ⇒ String
Optional.
-
#realm ⇒ String
Optional.
-
#registry_book ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomRange
constructor
A new instance of CustomRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomRange
Returns a new instance of CustomRange.
213 214 215 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 213 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::Attribute>
Optional. The attributes of the CustomRange.
Corresponds to the JSON property attributes
161 162 163 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 161 def attributes @attributes end |
#description ⇒ String
Optional. The description of the CustomRange.
Corresponds to the JSON property description
166 167 168 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 166 def description @description end |
#ipv4_cidr_range ⇒ String
Optional. The IPv4 CIDR range of the CustomRange.
Corresponds to the JSON property ipv4CidrRange
171 172 173 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 171 def ipv4_cidr_range @ipv4_cidr_range end |
#ipv6_cidr_range ⇒ String
Optional. The IPv6 CIDR range of the CustomRange.
Corresponds to the JSON property ipv6CidrRange
176 177 178 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 176 def ipv6_cidr_range @ipv6_cidr_range end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels.
Corresponds to the JSON property labels
181 182 183 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 181 def labels @labels end |
#name ⇒ String
Required. Identifier. The resource name of the CustomRange, in the format
projects/project/locations/location/customRanges/custom_range`.
Corresponds to the JSON propertyname`
187 188 189 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 187 def name @name end |
#parent_range ⇒ String
Optional. The resource name of the parent CustomRange, in the format projects/
project/locations/location/customRanges/custom_range`. If specified, the
parent CustomRange must be in the same RegistryBook. This field is mutually
exclusive with therealmfield, as the Realm is inherited from the parent
CustomRange.
Corresponds to the JSON propertyparentRange`
196 197 198 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 196 def parent_range @parent_range end |
#realm ⇒ String
Optional. The resource name of the Realm associated with the CustomRange, in
the format projects/project/locations/location/realms/realm`. The Realm
must be in the same project as the CustomRange. This field must not be set if
theparent_rangefield is set, as the Realm will be inherited from the
parent CustomRange.
Corresponds to the JSON propertyrealm`
205 206 207 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 205 def realm @realm end |
#registry_book ⇒ String
Output only. The RegistryBook of the CustomRange. This field is inherited from
the Realm or parent CustomRange depending on which one is specified.
Corresponds to the JSON property registryBook
211 212 213 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 211 def registry_book @registry_book end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 218 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @description = args[:description] if args.key?(:description) @ipv4_cidr_range = args[:ipv4_cidr_range] if args.key?(:ipv4_cidr_range) @ipv6_cidr_range = args[:ipv6_cidr_range] if args.key?(:ipv6_cidr_range) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @parent_range = args[:parent_range] if args.key?(:parent_range) @realm = args[:realm] if args.key?(:realm) @registry_book = args[:registry_book] if args.key?(:registry_book) end |