Class: Google::Apis::CloudnumberregistryV1alpha::CustomRange
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::CustomRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Message describing CustomRange object
Instance Attribute Summary collapse
-
#attributes ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::Attribute>
Optional.
-
#description ⇒ String
Optional.
-
#ipv4_cidr_range ⇒ String
Optional.
-
#ipv6_cidr_range ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Required.
-
#parent_range ⇒ String
Optional.
-
#realm ⇒ String
Optional.
-
#registry_book ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomRange
constructor
A new instance of CustomRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomRange
Returns a new instance of CustomRange.
208 209 210 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::Attribute>
Optional. The attributes of the CustomRange.
Corresponds to the JSON property attributes
160 161 162 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 160 def attributes @attributes end |
#description ⇒ String
Optional. Description of the CustomRange.
Corresponds to the JSON property description
165 166 167 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 165 def description @description end |
#ipv4_cidr_range ⇒ String
Optional. The IPv4 CIDR range of the CustomRange.
Corresponds to the JSON property ipv4CidrRange
170 171 172 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 170 def ipv4_cidr_range @ipv4_cidr_range end |
#ipv6_cidr_range ⇒ String
Optional. The IPv6 CIDR range of the CustomRange.
Corresponds to the JSON property ipv6CidrRange
175 176 177 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 175 def ipv6_cidr_range @ipv6_cidr_range end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs
Corresponds to the JSON property labels
180 181 182 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 180 def labels @labels end |
#name ⇒ String
Required. Identifier. name of resource
Corresponds to the JSON property name
185 186 187 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 185 def name @name end |
#parent_range ⇒ String
Optional. The parent range of the CustomRange. Do not allow setting parent
range if realm is specified. Format must follow this pattern: projects/
project/locations/location/customRanges/custom_range
Corresponds to the JSON property parentRange
192 193 194 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 192 def parent_range @parent_range end |
#realm ⇒ String
Optional. The realm of the CustomRange. The realm must be in the same project
as the custom range. Do not allow setting realm if parent range is specified,
since the realm should be inherited from the parent range. Format must follow
this pattern: projects/project/locations/location/realms/realm
Corresponds to the JSON property realm
200 201 202 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 200 def realm @realm end |
#registry_book ⇒ String
Output only. The registry book of the CustomRange. This field is inherited
from the realm or parent range depending on which one is specified.
Corresponds to the JSON property registryBook
206 207 208 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 206 def registry_book @registry_book end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 213 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @description = args[:description] if args.key?(:description) @ipv4_cidr_range = args[:ipv4_cidr_range] if args.key?(:ipv4_cidr_range) @ipv6_cidr_range = args[:ipv6_cidr_range] if args.key?(:ipv6_cidr_range) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @parent_range = args[:parent_range] if args.key?(:parent_range) @realm = args[:realm] if args.key?(:realm) @registry_book = args[:registry_book] if args.key?(:registry_book) end |