Class: Google::Apis::CloudnumberregistryV1alpha::DiscoveredRange

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb

Overview

Message describing DiscoveredRange object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveredRange

Returns a new instance of DiscoveredRange.



325
326
327
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesArray<Google::Apis::CloudnumberregistryV1alpha::Attribute>

Optional. The attributes of the DiscoveredRange. Corresponds to the JSON property attributes



261
262
263
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 261

def attributes
  @attributes
end

#child_cidr_overlap_allowedBoolean Also known as: child_cidr_overlap_allowed?

Output only. If true, allow child ranges of this range to overlap with each other. Corresponds to the JSON property childCidrOverlapAllowed

Returns:

  • (Boolean)


267
268
269
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 267

def child_cidr_overlap_allowed
  @child_cidr_overlap_allowed
end

#create_timeString

Output only. [Output only] Create time stamp Corresponds to the JSON property createTime

Returns:

  • (String)


273
274
275
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 273

def create_time
  @create_time
end

#descriptionString

Optional. Description of the DiscoveredRange. Corresponds to the JSON property description

Returns:

  • (String)


278
279
280
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 278

def description
  @description
end

#discovery_metadataGoogle::Apis::CloudnumberregistryV1alpha::DiscoveryMetadata

Discovery metadata of the discovered resource. Corresponds to the JSON property discoveryMetadata



283
284
285
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 283

def 
  @discovery_metadata
end

#ipv4_cidr_rangeString

Optional. The IPv4 CIDR range of the DiscoveredRange. Corresponds to the JSON property ipv4CidrRange

Returns:

  • (String)


288
289
290
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 288

def ipv4_cidr_range
  @ipv4_cidr_range
end

#ipv6_cidr_rangeString

Optional. The IPv6 CIDR range of the DiscoveredRange. Corresponds to the JSON property ipv6CidrRange

Returns:

  • (String)


293
294
295
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 293

def ipv6_cidr_range
  @ipv6_cidr_range
end

#labelsHash<String,String>

Optional. Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


298
299
300
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 298

def labels
  @labels
end

#nameString

Required. Identifier. Name of the DiscoveredRange. Corresponds to the JSON property name

Returns:

  • (String)


303
304
305
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 303

def name
  @name
end

#parent_rangeString

Optional. The parent range of the DiscoveredRange. Corresponds to the JSON property parentRange

Returns:

  • (String)


308
309
310
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 308

def parent_range
  @parent_range
end

#realmString

Optional. The realm of the DiscoveredRange. Corresponds to the JSON property realm

Returns:

  • (String)


313
314
315
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 313

def realm
  @realm
end

#registry_bookString

Output only. The registry book of the DiscoveredRange. Corresponds to the JSON property registryBook

Returns:

  • (String)


318
319
320
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 318

def registry_book
  @registry_book
end

#update_timeString

Output only. [Output only] Update time stamp Corresponds to the JSON property updateTime

Returns:

  • (String)


323
324
325
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 323

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 330

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @child_cidr_overlap_allowed = args[:child_cidr_overlap_allowed] if args.key?(:child_cidr_overlap_allowed)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @discovery_metadata = args[:discovery_metadata] if args.key?(:discovery_metadata)
  @ipv4_cidr_range = args[:ipv4_cidr_range] if args.key?(:ipv4_cidr_range)
  @ipv6_cidr_range = args[:ipv6_cidr_range] if args.key?(:ipv6_cidr_range)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @parent_range = args[:parent_range] if args.key?(:parent_range)
  @realm = args[:realm] if args.key?(:realm)
  @registry_book = args[:registry_book] if args.key?(:registry_book)
  @update_time = args[:update_time] if args.key?(:update_time)
end