Class: Google::Apis::CloudnumberregistryV1alpha::ListCustomRangesResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::ListCustomRangesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Response message for the CloudNumberRegistry.ListCustomRanges method.
Instance Attribute Summary collapse
-
#custom_ranges ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::CustomRange>
The list of CustomRanges.
-
#next_page_token ⇒ String
A token to retrieve the next page of results, or empty if there are no more results in the list.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCustomRangesResponse
constructor
A new instance of ListCustomRangesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCustomRangesResponse
Returns a new instance of ListCustomRangesResponse.
590 591 592 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_ranges ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::CustomRange>
The list of CustomRanges.
Corresponds to the JSON property customRanges
577 578 579 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 577 def custom_ranges @custom_ranges end |
#next_page_token ⇒ String
A token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
583 584 585 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 583 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
588 589 590 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 588 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
595 596 597 598 599 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 595 def update!(**args) @custom_ranges = args[:custom_ranges] if args.key?(:custom_ranges) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |