Class: Google::Apis::CloudnumberregistryV1alpha::ListCustomRangesResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::ListCustomRangesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Message for response to listing CustomRanges
Instance Attribute Summary collapse
-
#custom_ranges ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::CustomRange>
The list of CustomRange Corresponds to the JSON property
customRanges. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCustomRangesResponse
constructor
A new instance of ListCustomRangesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCustomRangesResponse
Returns a new instance of ListCustomRangesResponse.
575 576 577 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_ranges ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::CustomRange>
The list of CustomRange
Corresponds to the JSON property customRanges
563 564 565 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 563 def custom_ranges @custom_ranges end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
568 569 570 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 568 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
573 574 575 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 573 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
580 581 582 583 584 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 580 def update!(**args) @custom_ranges = args[:custom_ranges] if args.key?(:custom_ranges) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |