Class: Google::Apis::CloudnumberregistryV1alpha::ListDiscoveredRangesResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::ListDiscoveredRangesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Response message for the CloudNumberRegistry.ListDiscoveredRanges method.
Instance Attribute Summary collapse
-
#discovered_ranges ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::DiscoveredRange>
The list of DiscoveredRanges.
-
#next_page_token ⇒ String
A token to retrieve the next page of results, or empty if there are no more results in the list.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDiscoveredRangesResponse
constructor
A new instance of ListDiscoveredRangesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDiscoveredRangesResponse
Returns a new instance of ListDiscoveredRangesResponse.
622 623 624 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 622 def initialize(**args) update!(**args) end |
Instance Attribute Details
#discovered_ranges ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::DiscoveredRange>
The list of DiscoveredRanges.
Corresponds to the JSON property discoveredRanges
609 610 611 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 609 def discovered_ranges @discovered_ranges end |
#next_page_token ⇒ String
A token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
615 616 617 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 615 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
620 621 622 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 620 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
627 628 629 630 631 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 627 def update!(**args) @discovered_ranges = args[:discovered_ranges] if args.key?(:discovered_ranges) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |