Class: Google::Apis::CloudnumberregistryV1alpha::ListDiscoveredRangesResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::ListDiscoveredRangesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Message for response to listing DiscoveredRanges
Instance Attribute Summary collapse
-
#discovered_ranges ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::DiscoveredRange>
The list of DiscoveredRange Corresponds to the JSON property
discoveredRanges. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDiscoveredRangesResponse
constructor
A new instance of ListDiscoveredRangesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDiscoveredRangesResponse
Returns a new instance of ListDiscoveredRangesResponse.
606 607 608 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#discovered_ranges ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::DiscoveredRange>
The list of DiscoveredRange
Corresponds to the JSON property discoveredRanges
594 595 596 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 594 def discovered_ranges @discovered_ranges end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
599 600 601 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 599 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
604 605 606 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 604 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
611 612 613 614 615 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 611 def update!(**args) @discovered_ranges = args[:discovered_ranges] if args.key?(:discovered_ranges) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |