Class: Google::Apis::CloudnumberregistryV1alpha::ListIpamAdminScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::ListIpamAdminScopesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Response message for the CloudNumberRegistry.ListIpamAdminScopes method.
Instance Attribute Summary collapse
-
#ipam_admin_scopes ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::IpamAdminScope>
The list of IpamAdminScopes.
-
#next_page_token ⇒ String
A token to retrieve the next page of results, or empty if there are no more results in the list.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListIpamAdminScopesResponse
constructor
A new instance of ListIpamAdminScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListIpamAdminScopesResponse
Returns a new instance of ListIpamAdminScopesResponse.
654 655 656 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 654 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ipam_admin_scopes ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::IpamAdminScope>
The list of IpamAdminScopes.
Corresponds to the JSON property ipamAdminScopes
641 642 643 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 641 def ipam_admin_scopes @ipam_admin_scopes end |
#next_page_token ⇒ String
A token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
647 648 649 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 647 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
652 653 654 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 652 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
659 660 661 662 663 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 659 def update!(**args) @ipam_admin_scopes = args[:ipam_admin_scopes] if args.key?(:ipam_admin_scopes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |