Class: Google::Apis::CloudnumberregistryV1alpha::ListIpamAdminScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::ListIpamAdminScopesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Message for response to listing ipamAdminScopes
Instance Attribute Summary collapse
-
#ipam_admin_scopes ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::IpamAdminScope>
The list of IpamAdminScope Corresponds to the JSON property
ipamAdminScopes. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListIpamAdminScopesResponse
constructor
A new instance of ListIpamAdminScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListIpamAdminScopesResponse
Returns a new instance of ListIpamAdminScopesResponse.
637 638 639 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ipam_admin_scopes ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::IpamAdminScope>
The list of IpamAdminScope
Corresponds to the JSON property ipamAdminScopes
625 626 627 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 625 def ipam_admin_scopes @ipam_admin_scopes end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
630 631 632 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 630 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
635 636 637 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 635 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
642 643 644 645 646 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 642 def update!(**args) @ipam_admin_scopes = args[:ipam_admin_scopes] if args.key?(:ipam_admin_scopes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |