Class: Google::Apis::CloudnumberregistryV1alpha::ListRealmsResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::ListRealmsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Message for response to listing Realms
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#realms ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::Realm>
The list of Realm Corresponds to the JSON property
realms. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRealmsResponse
constructor
A new instance of ListRealmsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRealmsResponse
Returns a new instance of ListRealmsResponse.
727 728 729 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 727 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
715 716 717 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 715 def next_page_token @next_page_token end |
#realms ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::Realm>
The list of Realm
Corresponds to the JSON property realms
720 721 722 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 720 def realms @realms end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
725 726 727 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 725 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
732 733 734 735 736 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 732 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @realms = args[:realms] if args.key?(:realms) @unreachable = args[:unreachable] if args.key?(:unreachable) end |