Class: Google::Apis::CloudnumberregistryV1alpha::ListRegistryBooksResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::ListRegistryBooksResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Message for response to listing RegistryBooks
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#registry_books ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::RegistryBook>
The list of RegistryBook Corresponds to the JSON property
registryBooks. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRegistryBooksResponse
constructor
A new instance of ListRegistryBooksResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRegistryBooksResponse
Returns a new instance of ListRegistryBooksResponse.
758 759 760 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 758 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
746 747 748 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 746 def next_page_token @next_page_token end |
#registry_books ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::RegistryBook>
The list of RegistryBook
Corresponds to the JSON property registryBooks
751 752 753 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 751 def registry_books @registry_books end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
756 757 758 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 756 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
763 764 765 766 767 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 763 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @registry_books = args[:registry_books] if args.key?(:registry_books) @unreachable = args[:unreachable] if args.key?(:unreachable) end |