Class: Google::Apis::CloudnumberregistryV1alpha::Realm
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::Realm
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
A Realm represents a distinct network domain or security zone. It groups Ranges that share the same traffic and management characteristics. All the ranges in a Realm are routable to each other, meaning that they cannot overlap.
Instance Attribute Summary collapse
-
#aggregated_data ⇒ Google::Apis::CloudnumberregistryV1alpha::RealmAggregatedData
Aggregated data for the Realm.
-
#create_time ⇒ String
Output only.
-
#discovery_metadata ⇒ Google::Apis::CloudnumberregistryV1alpha::DiscoveryMetadata
Metadata about a discovered resource, tracking event times, state, and source information.
-
#ip_version ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#management_type ⇒ String
Required.
-
#name ⇒ String
Required.
-
#registry_book ⇒ String
Required.
-
#traffic_type ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Realm
constructor
A new instance of Realm.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Realm
Returns a new instance of Realm.
1079 1080 1081 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1079 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregated_data ⇒ Google::Apis::CloudnumberregistryV1alpha::RealmAggregatedData
Aggregated data for the Realm.
Corresponds to the JSON property aggregatedData
1031 1032 1033 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1031 def aggregated_data @aggregated_data end |
#create_time ⇒ String
Output only. The time at which the Realm was created.
Corresponds to the JSON property createTime
1036 1037 1038 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1036 def create_time @create_time end |
#discovery_metadata ⇒ Google::Apis::CloudnumberregistryV1alpha::DiscoveryMetadata
Metadata about a discovered resource, tracking event times, state, and source
information.
Corresponds to the JSON property discoveryMetadata
1042 1043 1044 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1042 def @discovery_metadata end |
#ip_version ⇒ String
Optional. IP version of the Realm.
Corresponds to the JSON property ipVersion
1047 1048 1049 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1047 def ip_version @ip_version end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels.
Corresponds to the JSON property labels
1052 1053 1054 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1052 def labels @labels end |
#management_type ⇒ String
Required. Management type of the Realm.
Corresponds to the JSON property managementType
1057 1058 1059 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1057 def management_type @management_type end |
#name ⇒ String
Required. Identifier. The resource name of the Realm.
Corresponds to the JSON property name
1062 1063 1064 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1062 def name @name end |
#registry_book ⇒ String
Required. Name of the RegistryBook that claims the Realm.
Corresponds to the JSON property registryBook
1067 1068 1069 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1067 def registry_book @registry_book end |
#traffic_type ⇒ String
Required. Traffic type of the Realm.
Corresponds to the JSON property trafficType
1072 1073 1074 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1072 def traffic_type @traffic_type end |
#update_time ⇒ String
Output only. The time at which the Realm was last updated.
Corresponds to the JSON property updateTime
1077 1078 1079 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1077 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1084 def update!(**args) @aggregated_data = args[:aggregated_data] if args.key?(:aggregated_data) @create_time = args[:create_time] if args.key?(:create_time) @discovery_metadata = args[:discovery_metadata] if args.key?(:discovery_metadata) @ip_version = args[:ip_version] if args.key?(:ip_version) @labels = args[:labels] if args.key?(:labels) @management_type = args[:management_type] if args.key?(:management_type) @name = args[:name] if args.key?(:name) @registry_book = args[:registry_book] if args.key?(:registry_book) @traffic_type = args[:traffic_type] if args.key?(:traffic_type) @update_time = args[:update_time] if args.key?(:update_time) end |