Class: Google::Apis::CloudnumberregistryV1alpha::Realm

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb

Overview

Message describing Realm object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Realm

Returns a new instance of Realm.



1056
1057
1058
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregated_dataGoogle::Apis::CloudnumberregistryV1alpha::RealmAggregatedData

Aggregated data for the Realm. Corresponds to the JSON property aggregatedData



1009
1010
1011
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1009

def aggregated_data
  @aggregated_data
end

#create_timeString

Output only. [Output only] Create time stamp Corresponds to the JSON property createTime

Returns:

  • (String)


1014
1015
1016
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1014

def create_time
  @create_time
end

#discovery_metadataGoogle::Apis::CloudnumberregistryV1alpha::DiscoveryMetadata

Discovery metadata of the discovered resource. Corresponds to the JSON property discoveryMetadata



1019
1020
1021
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1019

def 
  @discovery_metadata
end

#ip_versionString

Optional. IP version of the realm. Corresponds to the JSON property ipVersion

Returns:

  • (String)


1024
1025
1026
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1024

def ip_version
  @ip_version
end

#labelsHash<String,String>

Optional. Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1029
1030
1031
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1029

def labels
  @labels
end

#management_typeString

Required. Management type of realm. Corresponds to the JSON property managementType

Returns:

  • (String)


1034
1035
1036
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1034

def management_type
  @management_type
end

#nameString

Required. Identifier. Unique name/ID of the realm Corresponds to the JSON property name

Returns:

  • (String)


1039
1040
1041
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1039

def name
  @name
end

#registry_bookString

Required. URI of the registry book that claims the realm. Corresponds to the JSON property registryBook

Returns:

  • (String)


1044
1045
1046
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1044

def registry_book
  @registry_book
end

#traffic_typeString

Required. Traffic type of realm. Corresponds to the JSON property trafficType

Returns:

  • (String)


1049
1050
1051
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1049

def traffic_type
  @traffic_type
end

#update_timeString

Output only. [Output only] Update time stamp Corresponds to the JSON property updateTime

Returns:

  • (String)


1054
1055
1056
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1054

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1061

def update!(**args)
  @aggregated_data = args[:aggregated_data] if args.key?(:aggregated_data)
  @create_time = args[:create_time] if args.key?(:create_time)
  @discovery_metadata = args[:discovery_metadata] if args.key?(:discovery_metadata)
  @ip_version = args[:ip_version] if args.key?(:ip_version)
  @labels = args[:labels] if args.key?(:labels)
  @management_type = args[:management_type] if args.key?(:management_type)
  @name = args[:name] if args.key?(:name)
  @registry_book = args[:registry_book] if args.key?(:registry_book)
  @traffic_type = args[:traffic_type] if args.key?(:traffic_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end