Class: Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
Message for response to searching IP resources
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#ranges ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::Range>
Deprecated: Use results field instead.
-
#results ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResult>
The list of results matching the search query.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchIpResourcesResponse
constructor
A new instance of SearchIpResourcesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchIpResourcesResponse
Returns a new instance of SearchIpResourcesResponse.
1250 1251 1252 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1250 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1232 1233 1234 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1232 def next_page_token @next_page_token end |
#ranges ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::Range>
Deprecated: Use results field instead. The list of ranges matching the search
query.
Corresponds to the JSON property ranges
1238 1239 1240 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1238 def ranges @ranges end |
#results ⇒ Array<Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResult>
The list of results matching the search query.
Corresponds to the JSON property results
1243 1244 1245 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1243 def results @results end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1248 1249 1250 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1248 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1255 1256 1257 1258 1259 1260 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1255 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @ranges = args[:ranges] if args.key?(:ranges) @results = args[:results] if args.key?(:results) @unreachable = args[:unreachable] if args.key?(:unreachable) end |