Class: Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResult
- Inherits:
-
Object
- Object
- Google::Apis::CloudnumberregistryV1alpha::SearchIpResourcesResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudnumberregistry_v1alpha/classes.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb,
lib/google/apis/cloudnumberregistry_v1alpha/representations.rb
Overview
A result matching the search query, which can be either a Range or a Realm.
Instance Attribute Summary collapse
-
#range ⇒ Google::Apis::CloudnumberregistryV1alpha::Range
Represents either a CustomRange or a DiscoveredRange.
-
#realm ⇒ Google::Apis::CloudnumberregistryV1alpha::Realm
A Realm represents a distinct network domain or security zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchIpResourcesResult
constructor
A new instance of SearchIpResourcesResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchIpResourcesResult
Returns a new instance of SearchIpResourcesResult.
1309 1310 1311 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1309 def initialize(**args) update!(**args) end |
Instance Attribute Details
#range ⇒ Google::Apis::CloudnumberregistryV1alpha::Range
Represents either a CustomRange or a DiscoveredRange.
Corresponds to the JSON property range
1300 1301 1302 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1300 def range @range end |
#realm ⇒ Google::Apis::CloudnumberregistryV1alpha::Realm
A Realm represents a distinct network domain or security zone. It groups
Ranges that share the same traffic and management characteristics. All the
ranges in a Realm are routable to each other, meaning that they cannot overlap.
Corresponds to the JSON property realm
1307 1308 1309 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1307 def realm @realm end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1314 1315 1316 1317 |
# File 'lib/google/apis/cloudnumberregistry_v1alpha/classes.rb', line 1314 def update!(**args) @range = args[:range] if args.key?(:range) @realm = args[:realm] if args.key?(:realm) end |